==> flutter_unity_widget-0.1.0.tar.gz: lib/flutter_unity_widget.dart <==
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

typedef void FlutterUnityWidgetCreatedCallback(UnityWidgetController controller);


class UnityWidgetController {
  static MethodChannel _channel =
  const MethodChannel('unity_view');

  UnityWidgetController();

  init(int id) {
    _channel =  new MethodChannel('unity_view');
  }

  static Future<bool> isReady() async {
    final bool isReady = await _channel.invokeMethod('isReady');
    return isReady;
  }

  static Future<bool> createUnity() async {
    final bool isReady = await _channel.invokeMethod('createUnity');
    return isReady;
  }
  

  static postMessage(String gameObject, methodName, message){
    _channel.invokeMethod('postMessage', [gameObject, methodName, message]);
  }

  static pause() async{
    await _channel.invokeMethod('pause');
  }

  static resume() async{
    await _channel.invokeMethod('resume');
  }
}

class UnityWidget extends StatefulWidget {

  UnityWidgetController onUnityViewCreated;

  UnityWidget({
    Key key,
    @required this.onUnityViewCreated,
  });

  @override
  _UnityWidgetState createState() => _UnityWidgetState();
}

class _UnityWidgetState extends State<UnityWidget> {
  @override
  Widget build(BuildContext context) {
    if(defaultTargetPlatform == TargetPlatform.android) {
      return AndroidView(
        viewType: 'unityview',
        onPlatformViewCreated: onPlatformViewCreated,
        creationParamsCodec: const StandardMessageCodec(),

      );
    } else if(defaultTargetPlatform == TargetPlatform.iOS) {
      return UiKitView(
        viewType: 'unityview',
        onPlatformViewCreated: onPlatformViewCreated,
        creationParamsCodec: const StandardMessageCodec(),
      );
    }

    return new Text('$defaultTargetPlatform is not yet supported by this plugin');
  }

  Future<void> onPlatformViewCreated(id) async {
    if (widget.onUnityViewCreated == null) {
      return;
    }
    widget.onUnityViewCreated = new UnityWidgetController().init(id);
  }
}

==> flutter_unity_widget-0.1.1.tar.gz: lib/flutter_unity_widget.dart <==
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

typedef void FlutterUnityWidgetCreatedCallback(UnityWidgetController controller);


class UnityWidgetController {
  static MethodChannel _channel =
  const MethodChannel('unity_view');

  UnityWidgetController();

  init(int id) {
    _channel =  new MethodChannel('unity_view');
  }

  static Future<bool> isReady() async {
    final bool isReady = await _channel.invokeMethod('isReady');
    return isReady;
  }

  static Future<bool> createUnity() async {
    final bool isReady = await _channel.invokeMethod('createUnity');
    return isReady;
  }
  

  static postMessage(String gameObject, methodName, message){
    _channel.invokeMethod('postMessage', [gameObject, methodName, message]);
  }

  static pause() async{
    await _channel.invokeMethod('pause');
  }

  static resume() async{
    await _channel.invokeMethod('resume');
  }
}

class UnityWidget extends StatefulWidget {

  UnityWidgetController onUnityViewCreated;

  UnityWidget({
    Key key,
    @required this.onUnityViewCreated,
  });

  @override
  _UnityWidgetState createState() => _UnityWidgetState();
}

class _UnityWidgetState extends State<UnityWidget> {
  @override
  Widget build(BuildContext context) {
    if(defaultTargetPlatform == TargetPlatform.android) {
      return AndroidView(
        viewType: 'unity_view',
        onPlatformViewCreated: onPlatformViewCreated,
        creationParamsCodec: const StandardMessageCodec(),

      );
    } else if(defaultTargetPlatform == TargetPlatform.iOS) {
      return UiKitView(
        viewType: 'unity_view',
        onPlatformViewCreated: onPlatformViewCreated,
        creationParamsCodec: const StandardMessageCodec(),
      );
    }

    return new Text('$defaultTargetPlatform is not yet supported by this plugin');
  }

  Future<void> onPlatformViewCreated(id) async {
    if (widget.onUnityViewCreated == null) {
      return;
    }
    widget.onUnityViewCreated = new UnityWidgetController().init(id);
  }
}
